@@ -13,17 +13,17 @@ env_path = '/home/solcatcher/.env'
 def get_env_val(key):
     return get_env_value(key=key, path=env_path)
 
-RABBITMQ_HOST = get_env_val("SOLCATCHER_AMQP_HOST") or 'solcatcher.io'
-RABBITMQ_PORT = get_env_val("SOLCATCHER_AMQP_PORT") or '5672'
-RABBITMQ_USER = get_env_val("SOLCATCHER_AMQP_USER") or 'solcatcher'
-RABBITMQ_NAME = get_env_val("SOLCATCHER_AMQP_NAME") or 'solcatcher'
-RABBITMQ_PASSWORD = get_env_val("SOLCATCHER_AMQP_PASSWORD") or 'solcatcher123'
+RABBITMQ_HOST = get_env_val("SOLCATCHER_AMQP_HOST")
+RABBITMQ_PORT = get_env_val("SOLCATCHER_AMQP_PORT")
+RABBITMQ_USER = get_env_val("SOLCATCHER_AMQP_USER")
+RABBITMQ_NAME = get_env_val("SOLCATCHER_AMQP_NAME")
+RABBITMQ_PASSWORD = get_env_val("SOLCATCHER_AMQP_PASSWORD")
 
-POSTGRESQL_HOST = get_env_val("SOLCATCHER_POSTGRESQL_HOST") or 'solcatcher.io'
-POSTGRESQL_PORT = get_env_val("SOLCATCHER_POSTGRESQL_PORT") or '5432'
-POSTGRESQL_USER = get_env_val("SOLCATCHER_POSTGRESQL_USER") or 'solcatcher'
-POSTGRESQL_NAME = get_env_val("SOLCATCHER_POSTGRESQL_NAME") or 'solcatcher'
-POSTGRESQL_PASSWORD = get_env_val("SOLCATCHER_POSTGRESQL_PASSWORD") or 'solcatcher123!!!456'
+POSTGRESQL_HOST = get_env_val("SOLCATCHER_POSTGRESQL_HOST")
+POSTGRESQL_PORT = get_env_val("SOLCATCHER_POSTGRESQL_PORT")
+POSTGRESQL_USER = get_env_val("SOLCATCHER_POSTGRESQL_USER")
+POSTGRESQL_NAME = get_env_val("SOLCATCHER_POSTGRESQL_NAME")
+POSTGRESQL_PASSWORD = get_env_val("SOLCATCHER_POSTGRESQL_PASSWORD")
 
 DB_URL = f"postgresql://{POSTGRESQL_USER}:{POSTGRESQL_PASSWORD}@{POSTGRESQL_HOST}:{POSTGRESQL_PORT}/{POSTGRESQL_NAME}"
 
@@ -123,7 +123,7 @@ def fetch_any_combo(columnNames='*',
                     searchColumn=None,
                     searchValue=None,
                     anyValue=False,
-                    zipit=True,
+                    zipIt=True,
                     schema='public'):
     """
     Fetch rows based on dynamic SQL built from parameters.
@@ -165,8 +165,12 @@ def fetch_any_combo(columnNames='*',
             base_query += sql.SQL(" WHERE {} = %s").format(sql.Identifier(searchColumn))
             params.append(searchValue)
 
-    return query_data(base_query, values=params, zipRows=zipit)
-
+    
+    if zipIt:
+        result = query_data_as_dict(base_query, values=params)
+    else:
+        result = query_data(base_query, values=params, zipRows=zipit)
+    return result
 def get_anything(*args, **kwargs):
     if args:
         for arg in args:
